import { User } from "./identity";

export interface Idea {
  id: number;
  number: number;
  slug: string;
  title: string;
  description: string;
  createdOn: string;
  status: number;
  user: User;
  viewerSupported: boolean;
  response: IdeaResponse | null;
  totalSupporters: number;
  totalComments: number;
  tags: string[];
}

export class IdeaStatus {
  constructor(
    public value: number,
    public title: string,
    public slug: string,
    public show: boolean,
    public closed: boolean,
    public filterable: boolean
  ) {}

  public static Open = new IdeaStatus(0, "Open", "open", false, false, false);
  public static Planned = new IdeaStatus(4, "Planned", "planned", true, false, true);
  public static Started = new IdeaStatus(1, "Started", "started", true, false, true);
  public static Completed = new IdeaStatus(2, "Completed", "completed", true, true, true);
  public static Declined = new IdeaStatus(3, "Declined", "declined", true, true, true);
  public static Duplicate = new IdeaStatus(5, "Duplicate", "duplicate", true, true, false);
  public static Deleted = new IdeaStatus(6, "Deleted", "deleted", false, true, false);

  public static Get(value: number): IdeaStatus {
    for (const status of IdeaStatus.All) {
      if (status.value === value) {
        return status;
      }
    }
    throw new Error(`IdeaStatus not found for value ${value}.`);
  }

  public static All = [
    IdeaStatus.Open,
    IdeaStatus.Planned,
    IdeaStatus.Started,
    IdeaStatus.Completed,
    IdeaStatus.Duplicate,
    IdeaStatus.Declined
  ];
}

export interface IdeaResponse {
  user: User;
  text: string;
  respondedOn: Date;
  original?: {
    number: number;
    title: string;
    slug: string;
    status: number;
  };
}

export interface Comment {
  id: number;
  content: string;
  createdOn: string;
  user: User;
  editedOn?: string;
  editedBy?: User;
}

export interface Tag {
  id: number;
  slug: string;
  name: string;
  color: string;
  isPublic: boolean;
}
